==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/table/lang/da.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'da', {
	border: 'Rammebredde',
	caption: 'Titel',
	cell: {
		menu: 'Celle',
		insertBefore: 'Indsæt celle før',
		insertAfter: 'Indsæt celle efter',
		deleteCell: 'Slet celle',
		merge: 'Flet celler',
		mergeRight: 'Flet til højre',
		mergeDown: 'Flet nedad',
		splitHorizontal: 'Del celle vandret',
		splitVertical: 'Del celle lodret',
		title: 'Celleegenskaber',
		cellType: 'Celletype',
		rowSpan: 'Række span (rows span)',
		colSpan: 'Kolonne span (columns span)',
		wordWrap: 'Tekstombrydning',
		hAlign: 'Vandret justering',
		vAlign: 'Lodret justering',
		alignBaseline: 'Grundlinje',
		bgColor: 'Baggrundsfarve',
		borderColor: 'Rammefarve',
		data: 'Data',
		header: 'Hoved',
		yes: 'Ja',
		no: 'Nej',
		invalidWidth: 'Cellebredde skal være et tal.',
		invalidHeight: 'Cellehøjde skal være et tal.',
		invalidRowSpan: 'Række span skal være et heltal.',
		invalidColSpan: 'Kolonne span skal være et heltal.',
		chooseColor: 'Vælg'
	},
	cellPad: 'Cellemargen',
	cellSpace: 'Celleafstand',
	column: {
		menu: 'Kolonne',
		insertBefore: 'Indsæt kolonne før',
		insertAfter: 'Indsæt kolonne efter',
		deleteColumn: 'Slet kolonne'
	},
	columns: 'Kolonner',
	deleteTable: 'Slet tabel',
	headers: 'Hoved',
	headersBoth: 'Begge',
	headersColumn: 'Første kolonne',
	headersNone: 'Ingen',
	headersRow: 'Første række',
	heightUnit: 'højde enhed',
	invalidBorder: 'Rammetykkelse skal være et tal.',
	invalidCellPadding: 'Cellemargen skal være et tal.',
	invalidCellSpacing: 'Celleafstand skal være et tal.',
	invalidCols: 'Antallet af kolonner skal være større end 0.',
	invalidHeight: 'Tabelhøjde skal være et tal.',
	invalidRows: 'Antallet af rækker skal være større end 0.',
	invalidWidth: 'Tabelbredde skal være et tal.',
	menu: 'Egenskaber for tabel',
	row: {
		menu: 'Række',
		insertBefore: 'Indsæt række før',
		insertAfter: 'Indsæt række efter',
		deleteRow: 'Slet række'
	},
	rows: 'Rækker',
	summary: 'Resumé',
	title: 'Egenskaber for tabel',
	toolbar: 'Tabel',
	widthPc: 'procent',
	widthPx: 'pixels',
	widthUnit: 'Bredde på enhed'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/da.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'da', {
	border: 'Rammebredde',
	caption: 'Titel',
	cell: {
		menu: 'Celle',
		insertBefore: 'Indsæt celle før',
		insertAfter: 'Indsæt celle efter',
		deleteCell: 'Slet celle',
		merge: 'Flet celler',
		mergeRight: 'Flet til højre',
		mergeDown: 'Flet nedad',
		splitHorizontal: 'Del celle vandret',
		splitVertical: 'Del celle lodret',
		title: 'Celleegenskaber',
		cellType: 'Celletype',
		rowSpan: 'Række span (rows span)',
		colSpan: 'Kolonne span (columns span)',
		wordWrap: 'Tekstombrydning',
		hAlign: 'Vandret justering',
		vAlign: 'Lodret justering',
		alignBaseline: 'Grundlinje',
		bgColor: 'Baggrundsfarve',
		borderColor: 'Rammefarve',
		data: 'Data',
		header: 'Hoved',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Ja',
		no: 'Nej',
		invalidWidth: 'Cellebredde skal være et tal.',
		invalidHeight: 'Cellehøjde skal være et tal.',
		invalidRowSpan: 'Række span skal være et heltal.',
		invalidColSpan: 'Kolonne span skal være et heltal.',
		chooseColor: 'Vælg'
	},
	cellPad: 'Cellemargen',
	cellSpace: 'Celleafstand',
	column: {
		menu: 'Kolonne',
		insertBefore: 'Indsæt kolonne før',
		insertAfter: 'Indsæt kolonne efter',
		deleteColumn: 'Slet kolonne'
	},
	columns: 'Kolonner',
	deleteTable: 'Slet tabel',
	headers: 'Hoved',
	headersBoth: 'Begge',
	headersColumn: 'Første kolonne',
	headersNone: 'Ingen',
	headersRow: 'Første række',
	heightUnit: 'højde enhed',
	invalidBorder: 'Rammetykkelse skal være et tal.',
	invalidCellPadding: 'Cellemargen skal være et tal.',
	invalidCellSpacing: 'Celleafstand skal være et tal.',
	invalidCols: 'Antallet af kolonner skal være større end 0.',
	invalidHeight: 'Tabelhøjde skal være et tal.',
	invalidRows: 'Antallet af rækker skal være større end 0.',
	invalidWidth: 'Tabelbredde skal være et tal.',
	menu: 'Egenskaber for tabel',
	row: {
		menu: 'Række',
		insertBefore: 'Indsæt række før',
		insertAfter: 'Indsæt række efter',
		deleteRow: 'Slet række'
	},
	rows: 'Rækker',
	summary: 'Resumé',
	title: 'Egenskaber for tabel',
	toolbar: 'Tabel',
	widthPc: 'procent',
	widthPx: 'pixels',
	widthUnit: 'Bredde på enhed'
} );
